@@ -41,19 +41,13 @@ class TensorflowModelManager(ModelManager):
     @staticmethod
     def encode(model: tf.keras.Model) -> bytes:
         # save to folder - SavedModel standard
-        before = set(os.listdir())
         with tempfile.TemporaryDirectory() as temp_dir:
             tf.keras.models.save_model(model, temp_dir, save_format="tf")
 
             # we assume tar is available everywhere - it should be in almost all cases.
             with CustomNamedTemporaryFile() as temp:
-                try:
-                    with open(temp.name, "wb+") as f:
-                        encode_dir_to_file(pathlib.PurePath(temp_dir), f)
-                # TODO remove this if tempfile cleans up in error cases...
-                except Exception:
-                    clean_up(before=before, after=set(os.listdir()))
-                    raise
+                with open(temp.name, "wb+") as f:
+                    encode_dir_to_file(pathlib.PurePath(temp_dir), f)
 
                 with open(temp.name, "rb") as read_temp:
                     return read_temp.read()
@@ -66,7 +60,6 @@ class TensorflowModelManager(ModelManager):
         :param data:
         :return: XGBoost.Booster model.
         """
-        before = set(os.listdir())
         with CustomNamedTemporaryFile() as temp:
             with open(temp.name, "wb+") as write_temp:
                 write_temp.write(data)
@@ -78,9 +71,9 @@ class TensorflowModelManager(ModelManager):
             try:
                 model = tf.keras.models.load_model(dirname)
             except Exception:
-                clean_up(before=before, after=set(os.listdir()))
+                shutil.rmtree(dirname)
                 raise
-            clean_up(before=before, after=set(os.listdir()))
+            shutil.rmtree(dirname)
             return model
 
     @staticmethod
